@@ -86,8 +86,12 @@ class Client(object):
         return query
 
     # files
-    def list_file(self):
-        return self.workspace.file.list_absolute_path()
+    def list_file(self, recursive: bool = True):
+        """
+        Args:
+            recursive (bool): recursive list sub folder files
+        """
+        return self.workspace.file.list_absolute_path(recursive)
 
     def delete_file(self, absolute_path):
         return self.workspace.file.delete(absolute_path)
