@@ -32,6 +32,18 @@ def test_should_find_file_when_list_after_put_file_to_remote(
     assert expected in files, f"{expected} should exist in remote files when list"
 
 
+def test_should_find_filepath_when_list_after_put_filepath_to_remote(
+    cannerflow_client: Client, binary_filepaths: str
+):
+    expected = set(binary_filepaths)
+    # Act
+    for file in binary_filepaths:
+        cannerflow_client.put_binary(file, "")
+    files = cannerflow_client.list_file()
+    # Assert
+    assert set(files) == expected, f"{expected} should exist in remote files when list"
+
+
 def test_should_be_empty_after_delete_existed_file(cannerflow_client: Client):
     random_filename = str(uuid4().hex)
     expected = f"/{random_filename}"
